==> freedomdb-0.1.6.jar: project.clj <==
(defproject farbetter/freedomdb "0.1.6"
  :description "Freedom of choice for data storage"
  :url "https://github.com/farbetter/mu"
  :license {:name "The Apache Software License, Version 2.0"
            :url "http://www.apache.org/licenses/LICENSE-2.0.txt"}
  :lein-release {:scm :git
                 :deploy-via :clojars}

  :profiles {:dev
             {:plugins
              [[lein-cljsbuild "1.1.3"]
               [lein-release "1.0.9"]]}}

  :dependencies [[com.taoensso/timbre "4.3.1"]
                 [factual/clj-leveldb "0.1.1" :exclusions [primitive-math]]
                 [farbetter/utils "0.1.39"]
                 [org.clojure/clojure "1.8.0"]
                 [org.clojure/clojurescript "1.8.34"]
                 [org.clojure/data.avl "0.0.13"]
                 [prismatic/schema "1.0.5"]]

  :jvm-opts ^:replace ["-server" "-XX:+AggressiveOpts"]

  ;; Enable this to check for reflection problems
  ;; :global-vars {*warn-on-reflection* true}

  :test-selectors {:default (complement :perf)
                   :perf :perf
                   :the-one :the-one
                   :all (constantly true)}

  :cljsbuild
  {:builds
   [{:id "node-dev"
     :source-paths ["src" "test"]
     :notify-command ["node" "target/test/node_dev/test_main.js"]
     :compiler
     {:optimizations :none
      :main "freedomdb.test-runner"
      :target :nodejs
      :output-to "target/test/node_dev/test_main.js"
      :output-dir "target/test/node_dev"
      :source-map true}}
    {:id "node-perf"
     :source-paths ["src" "test"]
     :notify-command ["node" "target/test/node_perf/test_main.js" "perf"]
     :compiler
     {:optimizations :advanced
      :externs ["externs/node.js"]
      :target :nodejs
      :static-fns true
      :pretty-print false
      :output-to "target/test/node_perf/test_main.js"
      :output-dir "target/test/node_perf"
      :source-map "target/test/node_perf/map.js.map"}}]}

  :aliases
  {"auto-test-cljs" ["do"
                     "clean,"
                     "cljsbuild" "auto" "node-dev"]
   "auto-perf-cljs" ["do"
                     "clean,"
                     "cljsbuild" "auto" "node-perf"]})

==> freedomdb-0.1.9.jar: project.clj <==
(defproject farbetter/freedomdb "0.1.9"
  :description "Freedom of choice for data storage"
  :url "https://github.com/farbetter/mu"
  :license {:name "The Apache Software License, Version 2.0"
            :url "http://www.apache.org/licenses/LICENSE-2.0.txt"}
  :lein-release {:scm :git
                 :deploy-via :clojars}

  :profiles {:dev
             {:plugins
              [[lein-cljsbuild "1.1.3"]]}}

  :dependencies [[com.taoensso/timbre "4.3.1"]
                 [factual/clj-leveldb "0.1.1" :exclusions [primitive-math]]
                 [farbetter/utils "0.1.43"]
                 [org.clojure/clojure "1.8.0"]
                 [org.clojure/clojurescript "1.8.51"]
                 [org.clojure/data.avl "0.0.13"]
                 [prismatic/schema "1.1.1"]]

  :jvm-opts ^:replace ["-server" "-XX:+AggressiveOpts"]

  ;; Enable this to check for reflection problems
  ;; :global-vars {*warn-on-reflection* true}

  :test-selectors {:default (complement :perf)
                   :perf :perf
                   :the-one :the-one
                   :all (constantly true)}

  :cljsbuild
  {:builds
   [{:id "node-dev"
     :source-paths ["src" "test"]
     :notify-command ["node" "target/test/node_dev/test_main.js"]
     :compiler
     {:optimizations :none
      :main "freedomdb.test-runner"
      :target :nodejs
      :output-to "target/test/node_dev/test_main.js"
      :output-dir "target/test/node_dev"
      :source-map true}}
    {:id "node-perf"
     :source-paths ["src" "test"]
     :notify-command ["node" "target/test/node_perf/test_main.js" "perf"]
     :compiler
     {:optimizations :advanced
      :externs ["externs/node.js"]
      :target :nodejs
      :static-fns true
      :pretty-print false
      :output-to "target/test/node_perf/test_main.js"
      :output-dir "target/test/node_perf"
      :source-map "target/test/node_perf/map.js.map"}}]}

  :aliases
  {"auto-test-cljs" ["do"
                     "clean,"
                     "cljsbuild" "auto" "node-dev"]
   "auto-perf-cljs" ["do"
                     "clean,"
                     "cljsbuild" "auto" "node-perf"]})
